==> snipe-it-5.1.8.zip: snipe-it-5.1.8/resources/lang/bg/admin/custom_fields/general.php <==
<?php

return array(
    'custom_fields'		        => 'Потребителски полета',
    'field'		                => 'Поле',
    'about_fieldsets_title'		=> 'Относно Fieldsets',
    'about_fieldsets_text'		=> 'Fieldsets позволяват създаването на групи от персонализирани полета, които се използват и преизползват често за специфични типове модели на активи.',
    'custom_format'             => 'Персонализиран формат...',
    'encrypt_field'      	        => 'Шифроване на стойността на това поле в базата данни',
    'encrypt_field_help'      => 'ВНИМАНИЕ: Шифроване на поле го прави невалидно за търсене.',
    'encrypted'      	        => 'Шифровано',
    'fieldset'      	        => 'Fieldset',
    'qty_fields'      	      => 'Qty Fields',
    'fieldsets'      	        => 'Fieldsets',
    'fieldset_name'           => 'Fieldset имена',
    'field_name'              => 'Име на поле',
    'field_values'            => 'Стойност на поле',
    'field_values_help'       => 'Добавяне на избираеми опции, по една на ред. Празни редове, различни от първия ред ще бъдат пренебрегнати.',
    'field_element'           => 'Елемент на формуляра',
    'field_element_short'     => 'Елемент',
    'field_format'            => 'Формат',
    'field_custom_format'     => 'Персонализиран формат',
    'field_custom_format_help'     => 'Това поле позволява да използвате регулярен израз за валидация. За да го използвате, валидацията трябва да започва с "regex:" - например, за да потвърдите, че стойността на персонализираното поле съдържа валиден IMEI (15 цифри), можете да използвате <code>regex: / ^[0-9]{15}$ /</code>.',
    'required'   		          => 'Задължителен',
    'req'   		              => 'Req.',
    'used_by_models'   		    => 'Използвани от модели ',
    'order'   		            => 'Ред',
    'create_fieldset'         => 'Нов Fieldset',
    'create_field'            => 'Ново персонализирано поле',
    'value_encrypted'      	        => 'Стойността на това поле е криптирана в базата данни. Само администратор потребители ще бъде в състояние да видят дешифрираната стойност',
    'show_in_email'     => 'Да се включи ли стойността на това поле в електронната поща, изпращана към потребителите? Криптираните полета не могат да бъдат включвани в изпращаните електронни пощи.',
);

==> snipe-it-5.4.3.zip: snipe-it-5.4.3/resources/lang/bg/admin/custom_fields/general.php <==
<?php

return [
    'custom_fields'		        => 'Потребителски полета',
    'manage'                    => 'Manage',
    'field'		                => 'Поле',
    'about_fieldsets_title'		=> 'Относно Fieldsets',
    'about_fieldsets_text'		=> 'Fieldsets allow you to create groups of custom fields that are frequently re-used for specific asset model types.',
    'custom_format'             => 'Custom Regex format...',
    'encrypt_field'      	        => 'Шифроване на стойността на това поле в базата данни',
    'encrypt_field_help'      => 'ВНИМАНИЕ: Шифроване на поле го прави невалидно за търсене.',
    'encrypted'      	        => 'Шифровано',
    'fieldset'      	        => 'Fieldset',
    'qty_fields'      	      => 'Qty Fields',
    'fieldsets'      	        => 'Fieldsets',
    'fieldset_name'           => 'Fieldset имена',
    'field_name'              => 'Име на поле',
    'field_values'            => 'Стойност на поле',
    'field_values_help'       => 'Добавяне на избираеми опции, по една на ред. Празни редове, различни от първия ред ще бъдат пренебрегнати.',
    'field_element'           => 'Елемент на формуляра',
    'field_element_short'     => 'Елемент',
    'field_format'            => 'Формат',
    'field_custom_format'     => 'Персонализиран формат',
    'field_custom_format_help'     => 'Това поле позволява да използвате регулярен израз за валидация. За да го използвате, валидацията трябва да започва с "regex:" - например, за да потвърдите, че стойността на персонализираното поле съдържа валиден IMEI (15 цифри), можете да използвате <code>regex: / ^[0-9]{15}$ /</code>.',
    'required'   		          => 'Задължителен',
    'req'   		              => 'Req.',
    'used_by_models'   		    => 'Използвани от модели ',
    'order'   		            => 'Ред',
    'create_fieldset'         => 'Нов Fieldset',
    'create_fieldset_title' => 'Create a new fieldset',
    'create_field'            => 'Ново персонализирано поле',
    'create_field_title' => 'Create a new custom field',
    'value_encrypted'      	        => 'Стойността на това поле е криптирана в базата данни. Само администратор потребители ще бъде в състояние да видят дешифрираната стойност',
    'show_in_email'     => 'Да се включи ли стойността на това поле в електронната поща, изпращана към потребителите? Криптираните полета не могат да бъдат включвани в изпращаните електронни пощи.',
    'help_text' => 'Help Text',
    'help_text_description' => 'This is optional text that will appear below the form elements while editing an asset to provide context on the field.',
    'about_custom_fields_title' => 'About Custom Fields',
    'about_custom_fields_text' => 'Custom fields allow you to add arbitrary attributes to assets.',
    'add_field_to_fieldset' => 'Add Field to Fieldset',
    'make_optional' => 'Required - click to make optional',
    'make_required' => 'Optional - click to make required',
    'reorder' => 'Reorder',
    'db_field' => 'DB Field',
    'db_convert_warning' => 'WARNING. This field is in the custom fields table as <code> :db_column </code> but should be :expected </code>.',
    'is_unique' => 'This value must be unique across all assets',
    'unique' => 'Unique',
];
